@@ -21,10 +21,8 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
 
-from future.standard_library import install_aliases
-install_aliases()
-
 from typing import Any, List, Optional  # NOQA for mypy types
+import datetime
 
 from prestodb import constants
 import prestodb.exceptions
@@ -34,31 +32,15 @@ import prestodb.redirect
 from prestodb.transaction import Transaction, IsolationLevel, NO_TRANSACTION
 
 
-__all__ = ['connect', 'Connection', 'Cursor']
+__all__ = ["connect", "Connection", "Cursor"]
 
 
-apilevel = '2.0'
+apilevel = "2.0"
 threadsafety = 2
 
 logger = prestodb.logging.get_logger(__name__)
 
 
-class Error(Exception):
-    pass
-
-
-class OperationalError(Error):
-    """
-
-    Exception raised for errors that are related to the database's operation
-    and not necessarily under the control of the programmer, e.g. an unexpected
-    disconnect occurs, the data source name is not found, a transaction could
-    not be processed, a memory allocation error occurred during processing, ...
-
-    """
-    pass
-
-
 def connect(*args, **kwargs):
     """Constructor for creating a connection to the database.
 
@@ -76,6 +58,7 @@ class Connection(object):
     client implementation yet.
 
     """
+
     def __init__(
         self,
         host,
@@ -150,7 +133,7 @@ class Connection(object):
 
     def rollback(self):
         if self.transaction is None:
-            raise RuntimeError('no transaction was started')
+            raise RuntimeError("no transaction was started")
         self._transaction.rollback()
         self._transaction = None
 
@@ -175,7 +158,13 @@ class Connection(object):
 
     def cursor(self):
         """Return a new :py:class:`Cursor` object using the connection."""
-        return Cursor(self, self._create_request())
+        if self.isolation_level != IsolationLevel.AUTOCOMMIT:
+            if self.transaction is None:
+                self.start_transaction()
+            request = self.transaction._request
+        else:
+            request = self._create_request()
+        return Cursor(self, request)
 
 
 class Cursor(object):
@@ -185,12 +174,12 @@ class Cursor(object):
     cursor are immediately visible by other cursors or connections.
 
     """
+
     def __init__(self, connection, request):
         if not isinstance(connection, Connection):
             raise ValueError(
-                'connection must be a Connection object: {}'.format(
-                    type(connection)
-                ))
+                "connection must be a Connection object: {}".format(type(connection))
+            )
         self._connection = connection
         self._request = request
 
@@ -207,8 +196,10 @@ class Cursor(object):
         if self._query.columns is None:
             return None
 
+        # [ (name, type_code, display_size, internal_size, precision, scale, null_ok) ]
         return [
-            (col['name'], col['type']) for col in self._query.columns
+            (col["name"], col["type"], None, None, None, None, None)
+            for col in self._query.columns
         ]
 
     @property
@@ -228,24 +219,27 @@ class Cursor(object):
             return self._query.stats
         return None
 
+    @property
+    def warnings(self):
+        if self._query is not None:
+            return self._query.warnings
+        return None
+
     def setinputsizes(self, sizes):
-        """Not supported"""
-        pass
+        raise prestodb.exceptions.NotSupportedError
 
     def setoutputsize(self, size, column):
-        """Not supported"""
-        pass
+        raise prestodb.exceptions.NotSupportedError
 
     def execute(self, operation, params=None):
-        if self.connection.isolation_level != IsolationLevel.AUTOCOMMIT:
-            if self.connection.transaction is None:
-                self.connection.start_transaction()
-
         self._query = prestodb.client.PrestoQuery(self._request, sql=operation)
         result = self._query.execute()
         self._iterator = iter(result)
         return result
 
+    def executemany(self, operation, seq_of_params):
+        raise prestodb.exceptions.NotSupportedError
+
     def fetchone(self):
         # type: () -> Optional[List[Any]]
         """
@@ -262,7 +256,7 @@ class Cursor(object):
         except StopIteration:
             return None
         except prestodb.exceptions.HttpError as err:
-            raise OperationalError(str(err))
+            raise prestodb.exceptions.OperationalError(str(err))
 
     def fetchmany(self, size=None):
         # type: (Optional[int]) -> List[List[Any]]
@@ -307,5 +301,56 @@ class Cursor(object):
 
     def cancel(self):
         if self._query is None:
-            raise OperationalError("Cancel query failed; no running query")
+            raise prestodb.exceptions.OperationalError(
+                "Cancel query failed; no running query"
+            )
         self._query.cancel()
+
+    def close(self):
+        self._connection.close()
+
+
+Date = datetime.date
+Time = datetime.time
+Timestamp = datetime.datetime
+DateFromTicks = datetime.date.fromtimestamp
+TimestampFromTicks = datetime.datetime.fromtimestamp
+
+
+def TimeFromTicks(ticks):
+    return datetime.time(*datetime.localtime(ticks)[3:6])
+
+
+def Binary(string):
+    return string.encode("utf-8")
+
+
+class DBAPITypeObject:
+    def __init__(self, *values):
+        self.values = [v.lower() for v in values]
+
+    def __eq__(self, other):
+        return other.lower() in self.values
+
+
+STRING = DBAPITypeObject("VARCHAR", "CHAR", "VARBINARY", "JSON", "IPADDRESS")
+
+BINARY = DBAPITypeObject(
+    "ARRAY", "MAP", "ROW", "HyperLogLog", "P4HyperLogLog", "QDigest"
+)
+
+NUMBER = DBAPITypeObject(
+    "BOOLEAN", "TINYINT", "SMALLINT", "INTEGER", "BIGINT", "REAL", "DOUBLE", "DECIMAL"
+)
+
+DATETIME = DBAPITypeObject(
+    "DATE",
+    "TIME",
+    "TIME WITH TIME ZONE",
+    "TIMESTAMP",
+    "TIMESTAMP WITH TIME ZONE",
+    "INTERVAL YEAR TO MONTH",
+    "INTERVAL DAY TO SECOND",
+)
+
+ROWID = DBAPITypeObject()  # nothing indicates row id in Presto
